@@ -22,7 +22,7 @@ class Cluster(BaseController):
         res = cls.query('fetchProfileClusters', limit=limit,
                         id=cls.get_current_user(), next=next_)
 
-        if res is None:
+        if res is None or res['fetchProfile'] is None or res['fetchProfile']['clusters'] is None:
             return []
         return [ClusterDetails(cluster, res['fetchProfile']['defaultClusterId'] == cluster['id'])
                 for cluster in res['fetchProfile']['clusters']]
