@@ -12,7 +12,6 @@ class TestLiveCLI(object):
         output = subprocess.check_output(['disco', 'login', '-u',
                                           os.environ.get(const.ENV_VAR_EMAIL_NAME), '-p',
                                           os.environ.get(const.ENV_VAR_PASSWORD_NAME)]).decode("utf-8")
-        print(output)
         assert output.splitlines()[-1] == "Signed in successfully"
         output = subprocess.check_output(['disco', 'job', 'list']).decode("utf-8")
-        assert output.find("Done ") >= 0
+        assert output.find("ID") >= 0
