@@ -8,7 +8,7 @@ class TestJobDetailsModel(BaseTest):
 
         job_id = self.random_str('job-id')
         job_name = self.random_str('job-name')
-        job_status = self.random_str('Working')
+        job_status = self.random_str('Running')
 
         tasks_summary = {
             'timeout': self.random_int(),
@@ -43,7 +43,7 @@ class TestJobDetailsModel(BaseTest):
 
         job_id = self.random_str('job-id')
         job_name = self.random_str('job-name')
-        job_status = self.random_str('Working')
+        job_status = self.random_str('Running')
 
         job_data = {
             'id': job_id,
